@@ -78,10 +78,10 @@ var PlacesOrganizer = {
     // Set up the search UI.
     PlacesSearchBox.init();
 
-//@line 85 "/usr/obj/ports/mozilla-firefox-3.0.11/mozilla/browser/components/places/content/places.js"
+//@line 85 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/places.js"
 
     window.addEventListener("AppCommand", this, true);
-//@line 107 "/usr/obj/ports/mozilla-firefox-3.0.11/mozilla/browser/components/places/content/places.js"
+//@line 107 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/places.js"
 
     // remove the "Properties" context-menu item, we've our own details pane
     document.getElementById("placesContext")
@@ -516,11 +516,7 @@ var PlacesOrganizer = {
     var backupsDir = dirSvc.get("Desk", Ci.nsILocalFile);
     fp.displayDirectory = backupsDir;
 
-    // Use YYYY-MM-DD (ISO 8601) as it doesn't contain illegal characters
-    // and makes the alphabetical order of multiple backup files more useful.
-    var date = (new Date).toLocaleFormat("%Y-%m-%d");
-    fp.defaultString = PlacesUIUtils.getFormattedString("bookmarksBackupFilenameJSON",
-                                                        [date]);
+    fp.defaultString = PlacesUtils.getBackupFilename();
 
     if (fp.show() != Ci.nsIFilePicker.returnCancel) {
       PlacesUtils.backupBookmarksToFile(fp.file, [PlacesUIUtils.leftPaneFolderId]);
@@ -529,9 +525,7 @@ var PlacesOrganizer = {
       var latestBackup = PlacesUtils.getMostRecentBackup();
       if (!latestBackup || latestBackup != fp.file) {
         latestBackup.remove(false);
-        var date = new Date().toLocaleFormat("%Y-%m-%d");
-        var name = PlacesUtils.getFormattedString("bookmarksArchiveFilename",
-                                                  [date]);
+        var name = PlacesUtils.getBackupFilename();
         fp.file.copyTo(this.bookmarksBackupDir, name);
       }
     }
@@ -711,9 +705,9 @@ var PlacesOrganizer = {
     // If the advanced query builder is showing, use that.
     var options = this.getCurrentOptions();
 
-//@line 739 "/usr/obj/ports/mozilla-firefox-3.0.11/mozilla/browser/components/places/content/places.js"
+//@line 733 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/places.js"
     var queries = this.getCurrentQueries();
-//@line 741 "/usr/obj/ports/mozilla-firefox-3.0.11/mozilla/browser/components/places/content/places.js"
+//@line 735 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/places.js"
 
     var placeSpec = PlacesUtils.history.queriesToQueryString(queries,
                                                              queries.length,
@@ -913,7 +907,7 @@ var PlacesSearchBox = {
     var searchModifiers = document.getElementById("searchModifiers");
     searchModifiers.hidden = false;
 
-//@line 945 "/usr/obj/ports/mozilla-firefox-3.0.11/mozilla/browser/components/places/content/places.js"
+//@line 939 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/places.js"
   },
 
   hideSearchUI: function PSB_hideSearchUI() {
@@ -930,7 +924,7 @@ var PlacesQueryBuilder = {
   queries: [],
   queryOptions: null,
 
-//@line 1424 "/usr/obj/ports/mozilla-firefox-3.0.11/mozilla/browser/components/places/content/places.js"
+//@line 1418 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/places.js"
 
   onScopeSelected: function PQB_onScopeSelected(aButton) {
     var id = aButton.getAttribute("id");
