@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/i386/mozilla-firefox-3.0.11/mozilla/browser/components/nsBrowserGlue.js"
+//@line 39 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserGlue.js"
 
 const Ci = Components.interfaces;
 const Cc = Components.classes;
@@ -373,6 +373,7 @@ BrowserGlue.prototype = {
                      getService(Ci.nsIPrefBranch);
 
     var importBookmarks = false;
+    var importBookmarksHTML = false;
     var restoreDefaultBookmarks = false;
     try {
       restoreDefaultBookmarks = prefBranch.getBoolPref("browser.bookmarks.restore_default_bookmarks");
@@ -386,7 +387,8 @@ BrowserGlue.prototype = {
     }
     else {
       try {
-        importBookmarks = prefBranch.getBoolPref("browser.places.importBookmarksHTML");
+        importBookmarks = importBookmarksHTML =
+          prefBranch.getBoolPref("browser.places.importBookmarksHTML");
       } catch(ex) {}
     }
 
@@ -430,11 +432,12 @@ BrowserGlue.prototype = {
           // Report the error, but ignore it.
           Cu.reportError(err);
         }
-        prefBranch.setBoolPref("browser.places.importBookmarksHTML", false);
-        if (restoreDefaultBookmarks)
-          prefBranch.setBoolPref("browser.bookmarks.restore_default_bookmarks",
-                                 false);
       }
+      if (importBookmarksHTML)
+        prefBranch.setBoolPref("browser.places.importBookmarksHTML", false);
+      if (restoreDefaultBookmarks)
+        prefBranch.setBoolPref("browser.bookmarks.restore_default_bookmarks",
+                               false);
     }
 
     // Initialize bookmark archiving on idle.
@@ -721,7 +724,7 @@ BrowserGlue.prototype = {
     }
   },
 
-//@line 769 "/usr/obj/i386/mozilla-firefox-3.0.11/mozilla/browser/components/nsBrowserGlue.js"
+//@line 772 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserGlue.js"
 
   // this returns the most recent non-popup browser window
   _getMostRecentBrowserWindow : function ()
@@ -729,7 +732,7 @@ BrowserGlue.prototype = {
     var wm = Cc["@mozilla.org/appshell/window-mediator;1"].
              getService(Components.interfaces.nsIWindowMediator);
 
-//@line 777 "/usr/obj/i386/mozilla-firefox-3.0.11/mozilla/browser/components/nsBrowserGlue.js"
+//@line 780 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserGlue.js"
     var win = wm.getMostRecentWindow("navigator:browser", true);
 
     // if we're lucky, this isn't a popup, and we can just return this
@@ -743,7 +746,7 @@ BrowserGlue.prototype = {
           win = nextWin;
       }
     }
-//@line 803 "/usr/obj/i386/mozilla-firefox-3.0.11/mozilla/browser/components/nsBrowserGlue.js"
+//@line 806 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserGlue.js"
 
     return win;
   },
